@@ -15,6 +15,7 @@
 import glob
 import json
 import os
+import re
 import sys
 
 from cliff.command import Command
@@ -104,15 +105,15 @@ class KayobeAnsibleMixin(object):
         tags = None if install else "config"
         playbooks = _build_playbook_list("kolla-ansible")
         self.run_kayobe_playbooks(parsed_args, playbooks, tags=tags,
-                                  ignore_limit=True, check=False)
+                                  ignore_limit=True)
         if service_config:
             playbooks = _build_playbook_list("kolla-openstack")
             self.run_kayobe_playbooks(parsed_args, playbooks,
-                                      ignore_limit=True, check=False)
+                                      ignore_limit=True)
         if bifrost_config:
             playbooks = _build_playbook_list("kolla-bifrost")
             self.run_kayobe_playbooks(parsed_args, playbooks,
-                                      ignore_limit=True, check=False)
+                                      ignore_limit=True)
 
 
 class KollaAnsibleMixin(object):
@@ -190,18 +191,27 @@ class HookDispatcher(CommandHook):
         self.logger.debug("Discovered the following hooks: %s" % hooks)
         return hooks
 
-    def hooks(self, config_path, target):
-        hooks = self._find_hooks(config_path, target)
+    def hooks(self, config_path, target, filter):
+        hooks_out = []
+        if filter == "all":
+            self.logger.debug("Skipping all hooks")
+            return hooks_out
+        hooks_in = self._find_hooks(config_path, target)
         # Hooks can be prefixed with a sequence number to adjust running order,
         # e.g 10-my-custom-playbook.yml. Sort by sequence number.
-        hooks = sorted(hooks, key=_split_hook_sequence_number)
-        # Resolve symlinks so that we can reference roles.
-        hooks = [os.path.realpath(hook) for hook in hooks]
-        return hooks
+        hooks_in = sorted(hooks_in, key=_split_hook_sequence_number)
+        for hook in hooks_in:
+            # Resolve symlinks so that we can reference roles.
+            hook = os.path.realpath(hook)
+            if filter and re.search(filter, hook):
+                self.logger.debug("Skipping hook: %s", hook)
+            else:
+                hooks_out.append(hook)
+        return hooks_out
 
     def run_hooks(self, parsed_args, target):
         config_path = parsed_args.config_path
-        hooks = self.hooks(config_path, target)
+        hooks = self.hooks(config_path, target, parsed_args.skip_hooks)
         if hooks:
             self.logger.debug("Running hooks: %s" % hooks)
             self.command.run_kayobe_playbooks(parsed_args, hooks)
@@ -229,6 +239,13 @@ class ControlHostBootstrap(KayobeAnsibleMixin, KollaAnsibleMixin, VaultMixin,
       exists.
     """
 
+    def get_parser(self, prog_name):
+        parser = super(ControlHostBootstrap, self).get_parser(prog_name)
+        group = parser.add_argument_group("Host Bootstrap")
+        group.add_argument("--add-known-hosts", action='store_true',
+                           help="add SSH known hosts entries for each host")
+        return parser
+
     def take_action(self, parsed_args):
         self.app.LOG.debug("Bootstrapping Kayobe Ansible control host")
         ansible.install_galaxy_roles(parsed_args)
@@ -244,7 +261,7 @@ class ControlHostBootstrap(KayobeAnsibleMixin, KollaAnsibleMixin, VaultMixin,
             ka_tags = "install"
         playbooks = _build_playbook_list("kolla-ansible")
         self.run_kayobe_playbooks(parsed_args, playbooks, tags=ka_tags,
-                                  ignore_limit=True, check=False)
+                                  ignore_limit=True)
 
         if passwords_exist:
             # If we are bootstrapping a control host for an existing
@@ -258,6 +275,11 @@ class ControlHostBootstrap(KayobeAnsibleMixin, KollaAnsibleMixin, VaultMixin,
             self.run_kayobe_playbooks(parsed_args, playbooks,
                                       ignore_limit=True)
 
+        if parsed_args.add_known_hosts:
+            self.app.LOG.debug("Adding to known_hosts")
+            playbooks = _build_playbook_list("ssh-known-host")
+            self.run_kayobe_playbooks(parsed_args, playbooks)
+
 
 class ControlHostUpgrade(KayobeAnsibleMixin, VaultMixin, Command):
     """Upgrade the Kayobe control environment.
@@ -279,7 +301,7 @@ class ControlHostUpgrade(KayobeAnsibleMixin, VaultMixin, Command):
         self.run_kayobe_playbooks(parsed_args, playbooks, ignore_limit=True)
         playbooks = _build_playbook_list("kolla-ansible")
         self.run_kayobe_playbooks(parsed_args, playbooks, tags="install",
-                                  ignore_limit=True, check=False)
+                                  ignore_limit=True)
 
 
 class ConfigurationDump(KayobeAnsibleMixin, VaultMixin, Command):
@@ -415,10 +437,12 @@ class SeedHypervisorHostConfigure(KollaAnsibleMixin, KayobeAnsibleMixin,
     * Optionally, create a virtualenv for remote target hosts.
     * Optionally, wipe unmounted disk partitions (--wipe-disks).
     * Configure user accounts, group associations, and authorised SSH keys.
+    * Configure SELinux.
     * Configure the host's network interfaces.
     * Configure a firewall.
     * Configure tuned profile.
     * Set sysctl parameters.
+    * Configure IP routing and source NAT.
     * Configure timezone and ntp.
     * Optionally, configure software RAID arrays.
     * Optionally, configure encryption.
@@ -561,7 +585,7 @@ class SeedHostConfigure(KollaAnsibleMixin, KayobeAnsibleMixin, VaultMixin,
     * Optionally, create a virtualenv for remote target hosts.
     * Optionally, wipe unmounted disk partitions (--wipe-disks).
     * Configure user accounts, group associations, and authorised SSH keys.
-    * Disable SELinux.
+    * Configure SELinux.
     * Configure the host's network interfaces.
     * Configure a firewall.
     * Configure tuned profile.
@@ -704,6 +728,7 @@ class SeedServiceDeploy(KollaAnsibleMixin, KayobeAnsibleMixin, VaultMixin,
 
         self.run_kolla_ansible_seed(parsed_args, "deploy-bifrost")
         playbooks = _build_playbook_list(
+            "seed-credentials",
             "seed-introspection-rules",
             "dell-switch-bmp")
         self.run_kayobe_playbooks(parsed_args, playbooks)
@@ -738,6 +763,7 @@ class SeedServiceUpgrade(KollaAnsibleMixin, KayobeAnsibleMixin, VaultMixin,
         self.run_kayobe_playbooks(parsed_args, playbooks)
         self.run_kolla_ansible_seed(parsed_args, "upgrade-bifrost")
         playbooks = _build_playbook_list(
+            "seed-credentials",
             "seed-introspection-rules",
             "dell-switch-bmp")
         self.run_kayobe_playbooks(parsed_args, playbooks)
@@ -866,13 +892,13 @@ class InfraVMHostConfigure(KayobeAnsibleMixin, VaultMixin,
     * Optionally, create a virtualenv for remote target hosts.
     * Optionally, wipe unmounted disk partitions (--wipe-disks).
     * Configure user accounts, group associations, and authorised SSH keys.
-    * Disable SELinux.
+    * Configure SELinux.
     * Configure the host's network interfaces.
     * Configure a firewall.
     * Configure tuned profile.
     * Set sysctl parameters.
     * Disable bootstrap interface configuration.
-    * Configure timezone.
+    * Configure timezone and ntp.
     * Optionally, configure software RAID arrays.
     * Optionally, configure encryption.
     * Configure LVM volumes.
@@ -1080,8 +1106,7 @@ class OvercloudDeprovision(KayobeAnsibleMixin, VaultMixin, Command):
 
     def take_action(self, parsed_args):
         self.app.LOG.debug("Deprovisioning overcloud")
-        playbooks = _build_playbook_list("kolla-bifrost-hostvars",
-                                         "overcloud-deprovision")
+        playbooks = _build_playbook_list("overcloud-deprovision")
         self.run_kayobe_playbooks(parsed_args, playbooks)
 
 
@@ -1114,7 +1139,7 @@ class OvercloudHostConfigure(KollaAnsibleMixin, KayobeAnsibleMixin, VaultMixin,
     * Optionally, create a virtualenv for remote target hosts.
     * Optionally, wipe unmounted disk partitions (--wipe-disks).
     * Configure user accounts, group associations, and authorised SSH keys.
-    * Disable SELinux.
+    * Configure SELinux.
     * Configure the host's network interfaces.
     * Configure a firewall.
     * Configure tuned profile.
@@ -1778,8 +1803,7 @@ class OvercloudPostConfigure(KayobeAnsibleMixin, VaultMixin, Command):
       Builder (DIB), if building deployment images locally.
     * Register ironic inspector introspection rules with the overcloud
       inspector service.
-    * Register a provisioning network with glance.
-    * Configure Grafana for control plane.
+    * Register a provisioning network with neutron.
     * Configure serial consoles for the ironic nodes
     """
 
@@ -1788,8 +1812,7 @@ class OvercloudPostConfigure(KayobeAnsibleMixin, VaultMixin, Command):
         playbooks = _build_playbook_list(
             "overcloud-ipa-images", "overcloud-introspection-rules",
             "overcloud-introspection-rules-dell-lldp-workaround",
-            "provision-net", "overcloud-grafana-configure",
-            "baremetal-compute-serial-console-post-config")
+            "provision-net", "baremetal-compute-serial-console-post-config")
         self.run_kayobe_playbooks(parsed_args, playbooks)
 
 
