@@ -15,6 +15,7 @@
 import argparse
 import errno
 import os
+import os.path
 import shutil
 import subprocess
 import tempfile
@@ -30,6 +31,8 @@ from kayobe import vault
 @mock.patch.dict(os.environ, clear=True)
 class TestCase(unittest.TestCase):
 
+    maxDiff = None
+
     @mock.patch.object(utils, "run_command")
     @mock.patch.object(ansible, "_get_vars_files")
     @mock.patch.object(ansible, "_validate_args")
@@ -43,13 +46,48 @@ class TestCase(unittest.TestCase):
         ansible.run_playbooks(parsed_args, ["playbook1.yml", "playbook2.yml"])
         expected_cmd = [
             "ansible-playbook",
+            "--inventory", utils.get_data_files_path("ansible", "inventory"),
             "--inventory", "/etc/kayobe/inventory",
             "-e", "@/etc/kayobe/vars-file1.yml",
             "-e", "@/etc/kayobe/vars-file2.yaml",
             "playbook1.yml",
             "playbook2.yml",
         ]
-        expected_env = {"KAYOBE_CONFIG_PATH": "/etc/kayobe"}
+        home = os.path.expanduser("~")
+        expected_env = {
+            "KAYOBE_CONFIG_PATH": "/etc/kayobe",
+            "ANSIBLE_ROLES_PATH": ":".join([
+                "/etc/kayobe/ansible/roles",
+                utils.get_data_files_path("ansible", "roles"),
+                home + "/.ansible/roles",
+                "/usr/share/ansible/roles",
+                "/etc/ansible/roles",
+            ]),
+            "ANSIBLE_COLLECTIONS_PATH": ":".join([
+                "/etc/kayobe/ansible/collections",
+                utils.get_data_files_path("ansible", "collections"),
+                home + "/.ansible/collections",
+                "/usr/share/ansible/collections",
+            ]),
+            "ANSIBLE_ACTION_PLUGINS": ":".join([
+                "/etc/kayobe/ansible/action_plugins",
+                utils.get_data_files_path("ansible", "action_plugins"),
+                home + "/.ansible/plugins/action",
+                "/usr/share/ansible/plugins/action",
+            ]),
+            "ANSIBLE_FILTER_PLUGINS": ":".join([
+                "/etc/kayobe/ansible/filter_plugins",
+                utils.get_data_files_path("ansible", "filter_plugins"),
+                home + "/.ansible/plugins/filter",
+                "/usr/share/ansible/plugins/filter",
+            ]),
+            "ANSIBLE_TEST_PLUGINS": ":".join([
+                "/etc/kayobe/ansible/test_plugins",
+                utils.get_data_files_path("ansible", "test_plugins"),
+                home + "/.ansible/plugins/test",
+                "/usr/share/ansible/plugins/test",
+            ]),
+        }
         mock_run.assert_called_once_with(expected_cmd, check_output=False,
                                          quiet=False, env=expected_env)
         mock_vars.assert_called_once_with(["/etc/kayobe"])
@@ -68,6 +106,7 @@ class TestCase(unittest.TestCase):
             "-b",
             "-C",
             "--config-path", "/path/to/config",
+            "-D",
             "--environment", "test-env",
             "-e", "ev_name1=ev_value1",
             "-i", "/path/to/inventory",
@@ -82,19 +121,55 @@ class TestCase(unittest.TestCase):
             "ansible-playbook",
             "-vv",
             "--list-tasks",
+            "--inventory", utils.get_data_files_path("ansible", "inventory"),
             "--inventory", "/path/to/inventory",
             "-e", "@/path/to/config/vars-file1.yml",
             "-e", "@/path/to/config/vars-file2.yaml",
             "-e", "ev_name1=ev_value1",
             "--become",
             "--check",
+            "--diff",
             "--limit", "group1:host",
             "--tags", "tag1,tag2",
             "playbook1.yml",
             "playbook2.yml",
         ]
-        expected_env = {"KAYOBE_CONFIG_PATH": "/path/to/config",
-                        "KAYOBE_ENVIRONMENT": "test-env"}
+        home = os.path.expanduser("~")
+        expected_env = {
+            "KAYOBE_CONFIG_PATH": "/path/to/config",
+            "KAYOBE_ENVIRONMENT": "test-env",
+            "ANSIBLE_ROLES_PATH": ":".join([
+                "/path/to/config/ansible/roles",
+                utils.get_data_files_path("ansible", "roles"),
+                home + "/.ansible/roles",
+                "/usr/share/ansible/roles",
+                "/etc/ansible/roles",
+            ]),
+            "ANSIBLE_COLLECTIONS_PATH": ":".join([
+                "/path/to/config/ansible/collections",
+                utils.get_data_files_path("ansible", "collections"),
+                home + "/.ansible/collections",
+                "/usr/share/ansible/collections",
+            ]),
+            "ANSIBLE_ACTION_PLUGINS": ":".join([
+                "/path/to/config/ansible/action_plugins",
+                utils.get_data_files_path("ansible", "action_plugins"),
+                home + "/.ansible/plugins/action",
+                "/usr/share/ansible/plugins/action",
+            ]),
+            "ANSIBLE_FILTER_PLUGINS": ":".join([
+                "/path/to/config/ansible/filter_plugins",
+                utils.get_data_files_path("ansible", "filter_plugins"),
+                home + "/.ansible/plugins/filter",
+                "/usr/share/ansible/plugins/filter",
+            ]),
+            "ANSIBLE_TEST_PLUGINS": ":".join([
+                "/path/to/config/ansible/test_plugins",
+                utils.get_data_files_path("ansible", "test_plugins"),
+                home + "/.ansible/plugins/test",
+                "/usr/share/ansible/plugins/test",
+            ]),
+        }
         mock_run.assert_called_once_with(expected_cmd, check_output=False,
                                          quiet=False, env=expected_env)
         mock_vars.assert_called_once_with(
@@ -117,6 +192,7 @@ class TestCase(unittest.TestCase):
             "--become",
             "--check",
             "--config-path", "/path/to/config",
+            "--diff",
             "--environment", "test-env",
             "--extra-vars", "ev_name1=ev_value1",
             "--inventory", "/path/to/inventory",
@@ -132,28 +208,37 @@ class TestCase(unittest.TestCase):
             "ansible-playbook",
             "--list-tasks",
             "--vault-password-file", "/path/to/kayobe-vault-password-helper",
+            "--inventory", utils.get_data_files_path("ansible", "inventory"),
             "--inventory", "/path/to/inventory",
             "-e", "@/path/to/config/vars-file1.yml",
             "-e", "@/path/to/config/vars-file2.yaml",
             "-e", "ev_name1=ev_value1",
             "--become",
             "--check",
+            "--diff",
             "--limit", "group1:host1",
             "--skip-tags", "tag3,tag4",
             "--tags", "tag1,tag2",
             "playbook1.yml",
             "playbook2.yml",
         ]
-        expected_env = {"KAYOBE_CONFIG_PATH": "/path/to/config",
-                        "KAYOBE_ENVIRONMENT": "test-env",
-                        "KAYOBE_VAULT_PASSWORD": "test-pass"}
+        expected_env = {
+            "KAYOBE_CONFIG_PATH": "/path/to/config",
+            "KAYOBE_ENVIRONMENT": "test-env",
+            "KAYOBE_VAULT_PASSWORD": "test-pass",
+            "ANSIBLE_ROLES_PATH": mock.ANY,
+            "ANSIBLE_COLLECTIONS_PATH": mock.ANY,
+            "ANSIBLE_ACTION_PLUGINS": mock.ANY,
+            "ANSIBLE_FILTER_PLUGINS": mock.ANY,
+            "ANSIBLE_TEST_PLUGINS": mock.ANY,
+        }
         expected_calls = [
             mock.call(["which", "kayobe-vault-password-helper"],
                       check_output=True, universal_newlines=True),
             mock.call(expected_cmd, check_output=False, quiet=False,
                       env=expected_env)
         ]
-        self.assertEqual(expected_calls, mock_run.mock_calls)
+        self.assertListEqual(expected_calls, mock_run.mock_calls)
         mock_vars.assert_called_once_with(
             ["/path/to/config", "/path/to/config/environments/test-env"])
 
@@ -176,10 +261,18 @@ class TestCase(unittest.TestCase):
         expected_cmd = [
             "ansible-playbook",
             "--vault-password-file", "/path/to/vault/pw",
+            "--inventory", utils.get_data_files_path("ansible", "inventory"),
             "--inventory", "/etc/kayobe/inventory",
             "playbook1.yml",
         ]
-        expected_env = {"KAYOBE_CONFIG_PATH": "/etc/kayobe"}
+        expected_env = {
+            "KAYOBE_CONFIG_PATH": "/etc/kayobe",
+            "ANSIBLE_ROLES_PATH": mock.ANY,
+            "ANSIBLE_COLLECTIONS_PATH": mock.ANY,
+            "ANSIBLE_ACTION_PLUGINS": mock.ANY,
+            "ANSIBLE_FILTER_PLUGINS": mock.ANY,
+            "ANSIBLE_TEST_PLUGINS": mock.ANY,
+        }
         mock_run.assert_called_once_with(expected_cmd, check_output=False,
                                          quiet=False, env=expected_env)
         mock_update.assert_called_once_with(mock.ANY, expected_env)
@@ -205,11 +298,19 @@ class TestCase(unittest.TestCase):
         expected_cmd = [
             "ansible-playbook",
             "--vault-password-file", "/path/to/kayobe-vault-password-helper",
+            "--inventory", utils.get_data_files_path("ansible", "inventory"),
             "--inventory", "/etc/kayobe/inventory",
             "playbook1.yml",
         ]
-        expected_env = {"KAYOBE_CONFIG_PATH": "/etc/kayobe",
-                        "KAYOBE_VAULT_PASSWORD": "test-pass"}
+        expected_env = {
+            "KAYOBE_CONFIG_PATH": "/etc/kayobe",
+            "KAYOBE_VAULT_PASSWORD": "test-pass",
+            "ANSIBLE_ROLES_PATH": mock.ANY,
+            "ANSIBLE_COLLECTIONS_PATH": mock.ANY,
+            "ANSIBLE_ACTION_PLUGINS": mock.ANY,
+            "ANSIBLE_FILTER_PLUGINS": mock.ANY,
+            "ANSIBLE_TEST_PLUGINS": mock.ANY,
+        }
         mock_run.assert_called_once_with(expected_cmd, check_output=False,
                                          quiet=False, env=expected_env)
 
@@ -249,23 +350,33 @@ class TestCase(unittest.TestCase):
             "tags": "tag3,tag4",
             "verbose_level": 0,
             "check": True,
+            "diff": True,
         }
         ansible.run_playbooks(parsed_args, ["playbook1.yml", "playbook2.yml"],
                               **kwargs)
         expected_cmd = [
             "ansible-playbook",
+            "--inventory", utils.get_data_files_path("ansible", "inventory"),
             "--inventory", "/etc/kayobe/inventory",
             "-e", "@/etc/kayobe/vars-file1.yml",
             "-e", "@/etc/kayobe/vars-file2.yaml",
             "-e", "ev_name1=ev_value1",
             "-e", "ev_name2='ev_value2'",
             "--check",
+            "--diff",
             "--limit", "group1:host1:&group2:host2",
             "--tags", "tag1,tag2,tag3,tag4",
             "playbook1.yml",
             "playbook2.yml",
         ]
-        expected_env = {"KAYOBE_CONFIG_PATH": "/etc/kayobe"}
+        expected_env = {
+            "KAYOBE_CONFIG_PATH": "/etc/kayobe",
+            "ANSIBLE_ROLES_PATH": mock.ANY,
+            "ANSIBLE_COLLECTIONS_PATH": mock.ANY,
+            "ANSIBLE_ACTION_PLUGINS": mock.ANY,
+            "ANSIBLE_FILTER_PLUGINS": mock.ANY,
+            "ANSIBLE_TEST_PLUGINS": mock.ANY,
+        }
         mock_run.assert_called_once_with(expected_cmd, check_output=False,
                                          quiet=False, env=expected_env)
         mock_vars.assert_called_once_with(["/etc/kayobe"])
@@ -288,13 +399,21 @@ class TestCase(unittest.TestCase):
                               limit="foo", ignore_limit=True)
         expected_cmd = [
             "ansible-playbook",
+            "--inventory", utils.get_data_files_path("ansible", "inventory"),
             "--inventory", "/etc/kayobe/inventory",
             "-e", "@/etc/kayobe/vars-file1.yml",
             "-e", "@/etc/kayobe/vars-file2.yaml",
             "playbook1.yml",
             "playbook2.yml",
         ]
-        expected_env = {"KAYOBE_CONFIG_PATH": "/etc/kayobe"}
+        expected_env = {
+            "KAYOBE_CONFIG_PATH": "/etc/kayobe",
+            "ANSIBLE_ROLES_PATH": mock.ANY,
+            "ANSIBLE_COLLECTIONS_PATH": mock.ANY,
+            "ANSIBLE_ACTION_PLUGINS": mock.ANY,
+            "ANSIBLE_FILTER_PLUGINS": mock.ANY,
+            "ANSIBLE_TEST_PLUGINS": mock.ANY,
+        }
         mock_run.assert_called_once_with(expected_cmd, check_output=False,
                                          quiet=False, env=expected_env)
         mock_vars.assert_called_once_with(["/etc/kayobe"])
@@ -319,11 +438,19 @@ class TestCase(unittest.TestCase):
                               **kwargs)
         expected_cmd = [
             "ansible-playbook",
+            "--inventory", utils.get_data_files_path("ansible", "inventory"),
             "--inventory", "/etc/kayobe/inventory",
             "playbook1.yml",
             "playbook2.yml",
         ]
-        expected_env = {"KAYOBE_CONFIG_PATH": "/etc/kayobe"}
+        expected_env = {
+            "KAYOBE_CONFIG_PATH": "/etc/kayobe",
+            "ANSIBLE_ROLES_PATH": mock.ANY,
+            "ANSIBLE_COLLECTIONS_PATH": mock.ANY,
+            "ANSIBLE_ACTION_PLUGINS": mock.ANY,
+            "ANSIBLE_FILTER_PLUGINS": mock.ANY,
+            "ANSIBLE_TEST_PLUGINS": mock.ANY,
+        }
         mock_run.assert_called_once_with(expected_cmd, check_output=False,
                                          quiet=False, env=expected_env)
         mock_vars.assert_called_once_with(["/etc/kayobe"])
@@ -343,12 +470,18 @@ class TestCase(unittest.TestCase):
         ansible.run_playbooks(parsed_args, ["playbook1.yml"])
         expected_cmd = [
             "ansible-playbook",
+            "--inventory", utils.get_data_files_path("ansible", "inventory"),
             "--inventory", "/etc/kayobe/inventory",
             "playbook1.yml",
         ]
         expected_env = {
             "ANSIBLE_CONFIG": "/etc/kayobe/ansible.cfg",
-            "KAYOBE_CONFIG_PATH": "/etc/kayobe"
+            "KAYOBE_CONFIG_PATH": "/etc/kayobe",
+            "ANSIBLE_ROLES_PATH": mock.ANY,
+            "ANSIBLE_COLLECTIONS_PATH": mock.ANY,
+            "ANSIBLE_ACTION_PLUGINS": mock.ANY,
+            "ANSIBLE_FILTER_PLUGINS": mock.ANY,
+            "ANSIBLE_TEST_PLUGINS": mock.ANY,
         }
         mock_run.assert_called_once_with(expected_cmd, check_output=False,
                                          quiet=False, env=expected_env)
@@ -371,12 +504,18 @@ class TestCase(unittest.TestCase):
         ansible.run_playbooks(parsed_args, ["playbook1.yml"])
         expected_cmd = [
             "ansible-playbook",
+            "--inventory", utils.get_data_files_path("ansible", "inventory"),
             "--inventory", "/etc/kayobe/inventory",
             "playbook1.yml",
         ]
         expected_env = {
             "ANSIBLE_CONFIG": "/path/to/ansible.cfg",
-            "KAYOBE_CONFIG_PATH": "/etc/kayobe"
+            "KAYOBE_CONFIG_PATH": "/etc/kayobe",
+            "ANSIBLE_ROLES_PATH": mock.ANY,
+            "ANSIBLE_COLLECTIONS_PATH": mock.ANY,
+            "ANSIBLE_ACTION_PLUGINS": mock.ANY,
+            "ANSIBLE_FILTER_PLUGINS": mock.ANY,
+            "ANSIBLE_TEST_PLUGINS": mock.ANY,
         }
         mock_run.assert_called_once_with(expected_cmd, check_output=False,
                                          quiet=False, env=expected_env)
@@ -426,7 +565,7 @@ class TestCase(unittest.TestCase):
                                          },
                                          check_output=True, tags=None,
                                          verbose_level=None, check=False,
-                                         list_tasks=False)
+                                         list_tasks=False, diff=False)
         mock_rmtree.assert_called_once_with(dump_dir)
         mock_listdir.assert_any_call(dump_dir)
         mock_read.assert_has_calls([
@@ -434,7 +573,7 @@ class TestCase(unittest.TestCase):
             mock.call(os.path.join(dump_dir, "host2.yml")),
         ])
 
-    @mock.patch.object(utils, 'galaxy_install', autospec=True)
+    @mock.patch.object(utils, 'galaxy_role_install', autospec=True)
     @mock.patch.object(utils, 'is_readable_file', autospec=True)
     @mock.patch.object(os, 'makedirs', autospec=True)
     def test_install_galaxy_roles(self, mock_mkdirs, mock_is_readable,
@@ -453,7 +592,7 @@ class TestCase(unittest.TestCase):
             "/etc/kayobe/ansible/requirements.yml")
         self.assertFalse(mock_mkdirs.called)
 
-    @mock.patch.object(utils, 'galaxy_install', autospec=True)
+    @mock.patch.object(utils, 'galaxy_role_install', autospec=True)
     @mock.patch.object(utils, 'is_readable_file', autospec=True)
     @mock.patch.object(os, 'makedirs', autospec=True)
     def test_install_galaxy_roles_with_kayobe_config(
@@ -471,12 +610,12 @@ class TestCase(unittest.TestCase):
                       force=False),
             mock.call("/etc/kayobe/ansible/requirements.yml",
                       "/etc/kayobe/ansible/roles", force=False)]
-        self.assertEqual(expected_calls, mock_install.call_args_list)
+        self.assertListEqual(expected_calls, mock_install.call_args_list)
         mock_is_readable.assert_called_once_with(
             "/etc/kayobe/ansible/requirements.yml")
         mock_mkdirs.assert_called_once_with("/etc/kayobe/ansible/roles")
 
-    @mock.patch.object(utils, 'galaxy_install', autospec=True)
+    @mock.patch.object(utils, 'galaxy_role_install', autospec=True)
     @mock.patch.object(utils, 'is_readable_file', autospec=True)
     @mock.patch.object(os, 'makedirs', autospec=True)
     def test_install_galaxy_roles_with_kayobe_config_forced(
@@ -494,12 +633,12 @@ class TestCase(unittest.TestCase):
                       force=True),
             mock.call("/etc/kayobe/ansible/requirements.yml",
                       "/etc/kayobe/ansible/roles", force=True)]
-        self.assertEqual(expected_calls, mock_install.call_args_list)
+        self.assertListEqual(expected_calls, mock_install.call_args_list)
         mock_is_readable.assert_called_once_with(
             "/etc/kayobe/ansible/requirements.yml")
         mock_mkdirs.assert_called_once_with("/etc/kayobe/ansible/roles")
 
-    @mock.patch.object(utils, 'galaxy_install', autospec=True)
+    @mock.patch.object(utils, 'galaxy_role_install', autospec=True)
     @mock.patch.object(utils, 'is_readable_file', autospec=True)
     @mock.patch.object(os, 'makedirs', autospec=True)
     def test_install_galaxy_roles_with_kayobe_config_mkdirs_failure(
@@ -520,6 +659,92 @@ class TestCase(unittest.TestCase):
             "/etc/kayobe/ansible/requirements.yml")
         mock_mkdirs.assert_called_once_with("/etc/kayobe/ansible/roles")
 
+    @mock.patch.object(utils, 'galaxy_collection_install', autospec=True)
+    @mock.patch.object(utils, 'is_readable_file', autospec=True)
+    @mock.patch.object(os, 'makedirs', autospec=True)
+    def test_install_galaxy_collections(self, mock_mkdirs, mock_is_readable,
+                                        mock_install):
+        parser = argparse.ArgumentParser()
+        ansible.add_args(parser)
+        parsed_args = parser.parse_args([])
+        mock_is_readable.return_value = {"result": False}
+
+        ansible.install_galaxy_collections(parsed_args)
+
+        mock_install.assert_called_once_with(utils.get_data_files_path(
+            "requirements.yml"), utils.get_data_files_path(
+            "ansible", "collections"), force=False)
+        mock_is_readable.assert_called_once_with(
+            "/etc/kayobe/ansible/requirements.yml")
+        self.assertFalse(mock_mkdirs.called)
+
+    @mock.patch.object(utils, 'galaxy_collection_install', autospec=True)
+    @mock.patch.object(utils, 'is_readable_file', autospec=True)
+    @mock.patch.object(os, 'makedirs', autospec=True)
+    def test_install_galaxy_collections_with_kayobe_config(
+            self, mock_mkdirs, mock_is_readable, mock_install):
+        parser = argparse.ArgumentParser()
+        ansible.add_args(parser)
+        parsed_args = parser.parse_args([])
+        mock_is_readable.return_value = {"result": True}
+
+        ansible.install_galaxy_collections(parsed_args)
+
+        expected_calls = [
+            mock.call(utils.get_data_files_path("requirements.yml"),
+                      utils.get_data_files_path("ansible", "collections"),
+                      force=False),
+            mock.call("/etc/kayobe/ansible/requirements.yml",
+                      "/etc/kayobe/ansible/collections", force=False)]
+        self.assertListEqual(expected_calls, mock_install.call_args_list)
+        mock_is_readable.assert_called_once_with(
+            "/etc/kayobe/ansible/requirements.yml")
+        mock_mkdirs.assert_called_once_with("/etc/kayobe/ansible/collections")
+
+    @mock.patch.object(utils, 'galaxy_collection_install', autospec=True)
+    @mock.patch.object(utils, 'is_readable_file', autospec=True)
+    @mock.patch.object(os, 'makedirs', autospec=True)
+    def test_install_galaxy_collections_with_kayobe_config_forced(
+            self, mock_mkdirs, mock_is_readable, mock_install):
+        parser = argparse.ArgumentParser()
+        ansible.add_args(parser)
+        parsed_args = parser.parse_args([])
+        mock_is_readable.return_value = {"result": True}
+
+        ansible.install_galaxy_collections(parsed_args, force=True)
+
+        expected_calls = [
+            mock.call(utils.get_data_files_path("requirements.yml"),
+                      utils.get_data_files_path("ansible", "collections"),
+                      force=True),
+            mock.call("/etc/kayobe/ansible/requirements.yml",
+                      "/etc/kayobe/ansible/collections", force=True)]
+        self.assertListEqual(expected_calls, mock_install.call_args_list)
+        mock_is_readable.assert_called_once_with(
+            "/etc/kayobe/ansible/requirements.yml")
+        mock_mkdirs.assert_called_once_with("/etc/kayobe/ansible/collections")
+
+    @mock.patch.object(utils, 'galaxy_collection_install', autospec=True)
+    @mock.patch.object(utils, 'is_readable_file', autospec=True)
+    @mock.patch.object(os, 'makedirs', autospec=True)
+    def test_install_galaxy_collections_with_kayobe_config_mkdirs_failure(
+            self, mock_mkdirs, mock_is_readable, mock_install):
+        parser = argparse.ArgumentParser()
+        ansible.add_args(parser)
+        parsed_args = parser.parse_args([])
+        mock_is_readable.return_value = {"result": True}
+        mock_mkdirs.side_effect = OSError(errno.EPERM)
+
+        self.assertRaises(exception.Error,
+                          ansible.install_galaxy_collections, parsed_args)
+
+        mock_install.assert_called_once_with(
+            utils.get_data_files_path("requirements.yml"),
+            utils.get_data_files_path("ansible", "collections"), force=False)
+        mock_is_readable.assert_called_once_with(
+            "/etc/kayobe/ansible/requirements.yml")
+        mock_mkdirs.assert_called_once_with("/etc/kayobe/ansible/collections")
+
     @mock.patch.object(utils, 'galaxy_remove', autospec=True)
     def test_prune_galaxy_roles(self, mock_remove):
         parser = argparse.ArgumentParser()
@@ -579,12 +804,20 @@ class TestCase(unittest.TestCase):
         ansible.run_playbooks(parsed_args, ["playbook1.yml", "playbook2.yml"])
         expected_cmd = [
             "ansible-playbook",
+            "--inventory", utils.get_data_files_path("ansible", "inventory"),
             "--inventory", "/etc/kayobe/inventory",
             "--inventory", "/etc/kayobe/environments/foobar/inventory",
             "playbook1.yml",
             "playbook2.yml",
         ]
-        expected_env = {"KAYOBE_CONFIG_PATH": "/etc/kayobe"}
+        expected_env = {
+            "KAYOBE_CONFIG_PATH": "/etc/kayobe",
+            "ANSIBLE_ROLES_PATH": mock.ANY,
+            "ANSIBLE_COLLECTIONS_PATH": mock.ANY,
+            "ANSIBLE_ACTION_PLUGINS": mock.ANY,
+            "ANSIBLE_FILTER_PLUGINS": mock.ANY,
+            "ANSIBLE_TEST_PLUGINS": mock.ANY,
+        }
         mock_run.assert_called_once_with(expected_cmd, check_output=False,
                                          quiet=False, env=expected_env)
         mock_vars.assert_called_once_with(["/etc/kayobe"])
@@ -611,19 +844,27 @@ class TestCase(unittest.TestCase):
         ansible.run_playbooks(parsed_args, ["playbook1.yml", "playbook2.yml"])
         expected_cmd = [
             "ansible-playbook",
+            "--inventory", utils.get_data_files_path("ansible", "inventory"),
             "--inventory", "/etc/kayobe/inventory",
             "--inventory", "/etc/kayobe/environments/test-env/inventory",
             "playbook1.yml",
             "playbook2.yml",
         ]
-        expected_env = {"KAYOBE_CONFIG_PATH": "/etc/kayobe",
-                        "KAYOBE_ENVIRONMENT": "test-env"}
+        expected_env = {
+            "KAYOBE_CONFIG_PATH": "/etc/kayobe",
+            "KAYOBE_ENVIRONMENT": "test-env",
+            "ANSIBLE_ROLES_PATH": mock.ANY,
+            "ANSIBLE_COLLECTIONS_PATH": mock.ANY,
+            "ANSIBLE_ACTION_PLUGINS": mock.ANY,
+            "ANSIBLE_FILTER_PLUGINS": mock.ANY,
+            "ANSIBLE_TEST_PLUGINS": mock.ANY,
+        }
         expected_calls = [
             mock.call("/etc/kayobe/inventory"),
             mock.call("/etc/kayobe/environments/test-env/inventory"),
             mock.call("/etc/kayobe/ansible.cfg"),
         ]
-        self.assertEqual(expected_calls, mock_exists.mock_calls)
+        self.assertListEqual(expected_calls, mock_exists.mock_calls)
         mock_run.assert_called_once_with(expected_cmd, check_output=False,
                                          quiet=False, env=expected_env)
         mock_vars.assert_called_once_with(
@@ -651,18 +892,26 @@ class TestCase(unittest.TestCase):
         ansible.run_playbooks(parsed_args, ["playbook1.yml", "playbook2.yml"])
         expected_cmd = [
             "ansible-playbook",
+            "--inventory", utils.get_data_files_path("ansible", "inventory"),
             "--inventory", "/etc/kayobe/inventory",
             "playbook1.yml",
             "playbook2.yml",
         ]
-        expected_env = {"KAYOBE_CONFIG_PATH": "/etc/kayobe",
-                        "KAYOBE_ENVIRONMENT": "test-env"}
+        expected_env = {
+            "KAYOBE_CONFIG_PATH": "/etc/kayobe",
+            "KAYOBE_ENVIRONMENT": "test-env",
+            "ANSIBLE_ROLES_PATH": mock.ANY,
+            "ANSIBLE_COLLECTIONS_PATH": mock.ANY,
+            "ANSIBLE_ACTION_PLUGINS": mock.ANY,
+            "ANSIBLE_FILTER_PLUGINS": mock.ANY,
+            "ANSIBLE_TEST_PLUGINS": mock.ANY,
+        }
         expected_calls = [
             mock.call("/etc/kayobe/inventory"),
             mock.call("/etc/kayobe/environments/test-env/inventory"),
             mock.call("/etc/kayobe/ansible.cfg"),
         ]
-        self.assertEqual(expected_calls, mock_exists.mock_calls)
+        self.assertListEqual(expected_calls, mock_exists.mock_calls)
         mock_run.assert_called_once_with(expected_cmd, check_output=False,
                                          quiet=False, env=expected_env)
         mock_vars.assert_called_once_with(
@@ -690,18 +939,26 @@ class TestCase(unittest.TestCase):
         ansible.run_playbooks(parsed_args, ["playbook1.yml", "playbook2.yml"])
         expected_cmd = [
             "ansible-playbook",
+            "--inventory", utils.get_data_files_path("ansible", "inventory"),
             "--inventory", "/etc/kayobe/environments/test-env/inventory",
             "playbook1.yml",
             "playbook2.yml",
         ]
-        expected_env = {"KAYOBE_CONFIG_PATH": "/etc/kayobe",
-                        "KAYOBE_ENVIRONMENT": "test-env"}
+        expected_env = {
+            "KAYOBE_CONFIG_PATH": "/etc/kayobe",
+            "KAYOBE_ENVIRONMENT": "test-env",
+            "ANSIBLE_ROLES_PATH": mock.ANY,
+            "ANSIBLE_COLLECTIONS_PATH": mock.ANY,
+            "ANSIBLE_ACTION_PLUGINS": mock.ANY,
+            "ANSIBLE_FILTER_PLUGINS": mock.ANY,
+            "ANSIBLE_TEST_PLUGINS": mock.ANY,
+        }
         expected_calls = [
             mock.call("/etc/kayobe/inventory"),
             mock.call("/etc/kayobe/environments/test-env/inventory"),
             mock.call("/etc/kayobe/ansible.cfg"),
         ]
-        self.assertEqual(expected_calls, mock_exists.mock_calls)
+        self.assertListEqual(expected_calls, mock_exists.mock_calls)
         mock_run.assert_called_once_with(expected_cmd, check_output=False,
                                          quiet=False, env=expected_env)
         mock_vars.assert_called_once_with(
