@@ -16,9 +16,9 @@ import argparse
 import os
 import subprocess
 import unittest
+from unittest import mock
 
-import mock
-
+from kayobe import ansible
 from kayobe import kolla_ansible
 from kayobe import utils
 from kayobe import vault
@@ -28,10 +28,13 @@ from kayobe import vault
 @mock.patch.dict(os.environ, clear=True)
 class TestCase(unittest.TestCase):
 
+    maxDiff = None
+
     @mock.patch.object(utils, "run_command")
     @mock.patch.object(kolla_ansible, "_validate_args")
     def test_run(self, mock_validate, mock_run):
         parser = argparse.ArgumentParser()
+        ansible.add_args(parser)
         kolla_ansible.add_args(parser)
         vault.add_args(parser)
         parsed_args = parser.parse_args([])
@@ -49,47 +52,57 @@ class TestCase(unittest.TestCase):
     @mock.patch.object(kolla_ansible, "_validate_args")
     def test_run_all_the_args(self, mock_validate, mock_run):
         parser = argparse.ArgumentParser()
+        ansible.add_args(parser)
         kolla_ansible.add_args(parser)
         vault.add_args(parser)
         args = [
+            "-C",
+            "-D",
             "--kolla-config-path", "/path/to/config",
             "-ke", "ev_name1=ev_value1",
             "-ki", "/path/to/inventory",
             "-kl", "host1:host2",
             "-kt", "tag1,tag2",
+            "-kp", "/path/to/playbook",
         ]
         parsed_args = parser.parse_args(args)
         kolla_ansible.run(parsed_args, "command", "overcloud")
         expected_cmd = [
             ".", "/path/to/cwd/venvs/kolla-ansible/bin/activate", "&&",
             "kolla-ansible", "command",
+            "--playbook", "/path/to/playbook",
             "--inventory", "/path/to/inventory",
             "--configdir", "/path/to/config",
             "--passwords", "/path/to/config/passwords.yml",
             "-e", "ev_name1=ev_value1",
-            "--limit", "host1:host2",
+            "--limit", "'host1:host2'",
             "--tags", "tag1,tag2",
         ]
         expected_cmd = " ".join(expected_cmd)
+        expected_env = {"EXTRA_OPTS": " --check --diff"}
         mock_run.assert_called_once_with(expected_cmd, shell=True, quiet=False,
-                                         env={})
+                                         env=expected_env)
 
     @mock.patch.object(utils, "run_command")
     @mock.patch.object(kolla_ansible, "_validate_args")
     @mock.patch.object(vault, "_ask_vault_pass")
     def test_run_all_the_long_args(self, mock_ask, mock_validate, mock_run):
         parser = argparse.ArgumentParser()
+        ansible.add_args(parser)
         kolla_ansible.add_args(parser)
         vault.add_args(parser)
         mock_ask.return_value = "test-pass"
         args = [
             "--ask-vault-pass",
+            "--check",
+            "--diff",
             "--kolla-config-path", "/path/to/config",
             "--kolla-extra-vars", "ev_name1=ev_value1",
             "--kolla-inventory", "/path/to/inventory",
             "--kolla-limit", "host1:host2",
             "--kolla-skip-tags", "tag3,tag4",
             "--kolla-tags", "tag1,tag2",
+            "--kolla-playbook", "/path/to/playbook",
         ]
         parsed_args = parser.parse_args(args)
         mock_run.return_value = "/path/to/kayobe-vault-password-helper"
@@ -97,23 +110,25 @@ class TestCase(unittest.TestCase):
         expected_cmd = [
             ".", "/path/to/cwd/venvs/kolla-ansible/bin/activate", "&&",
             "kolla-ansible", "command",
+            "--playbook", "/path/to/playbook",
             "--key", "/path/to/kayobe-vault-password-helper",
             "--inventory", "/path/to/inventory",
             "--configdir", "/path/to/config",
             "--passwords", "/path/to/config/passwords.yml",
             "-e", "ev_name1=ev_value1",
-            "--limit", "host1:host2",
+            "--limit", "'host1:host2'",
             "--skip-tags", "tag3,tag4",
             "--tags", "tag1,tag2",
         ]
         expected_cmd = " ".join(expected_cmd)
-        expected_env = {"KAYOBE_VAULT_PASSWORD": "test-pass"}
+        expected_env = {"EXTRA_OPTS": " --check --diff",
+                        "KAYOBE_VAULT_PASSWORD": "test-pass"}
         expected_calls = [
             mock.call(["which", "kayobe-vault-password-helper"],
-                      check_output=True),
+                      check_output=True, universal_newlines=True),
             mock.call(expected_cmd, shell=True, quiet=False, env=expected_env)
         ]
-        self.assertEqual(expected_calls, mock_run.mock_calls)
+        self.assertListEqual(expected_calls, mock_run.mock_calls)
 
     @mock.patch.object(utils, "run_command")
     @mock.patch.object(kolla_ansible, "_validate_args")
@@ -121,6 +136,7 @@ class TestCase(unittest.TestCase):
     def test_run_vault_password_file(self, mock_update, mock_validate,
                                      mock_run):
         parser = argparse.ArgumentParser()
+        ansible.add_args(parser)
         kolla_ansible.add_args(parser)
         vault.add_args(parser)
         args = [
@@ -147,10 +163,12 @@ class TestCase(unittest.TestCase):
         mock_vars.return_value = []
         parser = argparse.ArgumentParser()
         mock_run.return_value = "/path/to/kayobe-vault-password-helper"
+        ansible.add_args(parser)
         kolla_ansible.add_args(parser)
         vault.add_args(parser)
         mock_run.assert_called_once_with(
-            ["which", "kayobe-vault-password-helper"], check_output=True)
+            ["which", "kayobe-vault-password-helper"], check_output=True,
+            universal_newlines=True)
         mock_run.reset_mock()
         parsed_args = parser.parse_args([])
         kolla_ansible.run(parsed_args, "command", "overcloud")
@@ -170,6 +188,7 @@ class TestCase(unittest.TestCase):
     @mock.patch.object(kolla_ansible, "_validate_args")
     def test_run_func_args(self, mock_validate, mock_run):
         parser = argparse.ArgumentParser()
+        ansible.add_args(parser)
         kolla_ansible.add_args(parser)
         vault.add_args(parser)
         args = [
@@ -190,7 +209,7 @@ class TestCase(unittest.TestCase):
             "-v",
             "--inventory", "/etc/kolla/inventory/overcloud",
             "-e", "ev_name1=ev_value1",
-            "-e", "ev_name2=ev_value2",
+            "-e", "ev_name2='ev_value2'",
             "--tags", "tag1,tag2,tag3,tag4",
             "--arg1", "--arg2",
         ]
@@ -198,10 +217,85 @@ class TestCase(unittest.TestCase):
         mock_run.assert_called_once_with(expected_cmd, shell=True, quiet=False,
                                          env={})
 
+    @mock.patch.object(utils, "run_command")
+    @mock.patch.object(utils, "is_readable_file")
+    @mock.patch.object(kolla_ansible, "_validate_args")
+    def test_run_custom_ansible_cfg(self, mock_validate, mock_readable,
+                                    mock_run):
+        mock_readable.return_value = {"result": True}
+        parser = argparse.ArgumentParser()
+        ansible.add_args(parser)
+        kolla_ansible.add_args(parser)
+        vault.add_args(parser)
+        parsed_args = parser.parse_args([])
+        kolla_ansible.run(parsed_args, "command", "overcloud")
+        expected_cmd = [
+            ".", "/path/to/cwd/venvs/kolla-ansible/bin/activate", "&&",
+            "kolla-ansible", "command",
+            "--inventory", "/etc/kolla/inventory/overcloud",
+        ]
+        expected_cmd = " ".join(expected_cmd)
+        expected_env = {"ANSIBLE_CONFIG": "/etc/kayobe/kolla/ansible.cfg"}
+        mock_run.assert_called_once_with(expected_cmd, shell=True, quiet=False,
+                                         env=expected_env)
+        mock_readable.assert_called_once_with("/etc/kayobe/kolla/ansible.cfg")
+
+    @mock.patch.object(utils, "run_command")
+    @mock.patch.object(utils, "is_readable_file")
+    @mock.patch.object(kolla_ansible, "_validate_args")
+    def test_run_custom_ansible_cfg_2(self, mock_validate, mock_readable,
+                                      mock_run):
+        mock_readable.side_effect = [{"result": False}, {"result": True}]
+        parser = argparse.ArgumentParser()
+        ansible.add_args(parser)
+        kolla_ansible.add_args(parser)
+        vault.add_args(parser)
+        parsed_args = parser.parse_args([])
+        kolla_ansible.run(parsed_args, "command", "overcloud")
+        expected_cmd = [
+            ".", "/path/to/cwd/venvs/kolla-ansible/bin/activate", "&&",
+            "kolla-ansible", "command",
+            "--inventory", "/etc/kolla/inventory/overcloud",
+        ]
+        expected_cmd = " ".join(expected_cmd)
+        expected_env = {"ANSIBLE_CONFIG": "/etc/kayobe/ansible.cfg"}
+        mock_run.assert_called_once_with(expected_cmd, shell=True, quiet=False,
+                                         env=expected_env)
+        expected_calls = [
+            mock.call("/etc/kayobe/kolla/ansible.cfg"),
+            mock.call("/etc/kayobe/ansible.cfg"),
+        ]
+        self.assertListEqual(mock_readable.call_args_list, expected_calls)
+
+    @mock.patch.object(utils, "run_command")
+    @mock.patch.object(utils, "is_readable_file")
+    @mock.patch.object(kolla_ansible, "_validate_args")
+    def test_run_custom_ansible_cfg_env(self, mock_validate, mock_readable,
+                                        mock_run):
+        mock_readable.return_value = {"result": True}
+        os.environ["ANSIBLE_CONFIG"] = "/path/to/ansible.cfg"
+        parser = argparse.ArgumentParser()
+        ansible.add_args(parser)
+        kolla_ansible.add_args(parser)
+        vault.add_args(parser)
+        parsed_args = parser.parse_args([])
+        kolla_ansible.run(parsed_args, "command", "overcloud")
+        expected_cmd = [
+            ".", "/path/to/cwd/venvs/kolla-ansible/bin/activate", "&&",
+            "kolla-ansible", "command",
+            "--inventory", "/etc/kolla/inventory/overcloud",
+        ]
+        expected_cmd = " ".join(expected_cmd)
+        expected_env = {"ANSIBLE_CONFIG": "/path/to/ansible.cfg"}
+        mock_run.assert_called_once_with(expected_cmd, shell=True, quiet=False,
+                                         env=expected_env)
+        mock_readable.assert_called_once_with("/etc/kayobe/kolla/ansible.cfg")
+
     @mock.patch.object(utils, "run_command")
     @mock.patch.object(kolla_ansible, "_validate_args")
     def test_run_failure(self, mock_validate, mock_run):
         parser = argparse.ArgumentParser()
+        ansible.add_args(parser)
         kolla_ansible.add_args(parser)
         vault.add_args(parser)
         parsed_args = parser.parse_args([])
